pub fn encode_to_bytes(
img: &DynamicImage,
cfg: &ProcessConfig,
) -> Result<Vec<u8>, String>Expand description
Encode image to raw bytes using the configured output format.
pub fn encode_to_bytes(
img: &DynamicImage,
cfg: &ProcessConfig,
) -> Result<Vec<u8>, String>Encode image to raw bytes using the configured output format.